@@ -10,6 +10,7 @@
 
 #include <KConfigGroup>
 #include <KLocalizedString>
+#include <KPluginFactory>
 #include <KPluginLoader>
 #include <KSharedConfig>
 #include <kde_terminal_interface.h>
@@ -124,3 +125,25 @@ bool KateProjectInfoViewTerminal::ignoreEsc() const
     const auto app = qobject_cast<TerminalInterface *>(m_konsolePart)->foregroundProcessName();
     return exceptList.contains(app);
 }
+
+bool KateProjectInfoViewTerminal::isLoadable()
+{
+    return (pluginFactory() != nullptr);
+}
+
+void KateProjectInfoViewTerminal::respawn(const QString &directory)
+{
+    if (!isLoadable()) {
+        return;
+    }
+
+    m_directory = directory;
+    disconnect(m_konsolePart, &KParts::ReadOnlyPart::destroyed, this, &KateProjectInfoViewTerminal::loadTerminal);
+
+    if (m_konsolePart != nullptr) {
+        delete m_konsolePart;
+    }
+
+    loadTerminal();
+}
+
