@@ -7,11 +7,13 @@
 
 #include "kateprojectplugin.h"
 
+#include "kateproject.h"
 #include "kateprojectconfigpage.h"
 #include "kateprojectpluginview.h"
 
 #include <ktexteditor/application.h>
 #include <ktexteditor/editor.h>
+#include <ktexteditor/view.h>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -19,6 +21,8 @@
 
 #include <QCoreApplication>
 #include <QFileInfo>
+#include <QMessageBox>
+#include <QString>
 #include <QTime>
 
 #include <vector>
@@ -203,6 +207,36 @@ KateProject *KateProjectPlugin::projectForDir(QDir dir, bool userSpecified)
     return nullptr;
 }
 
+bool KateProjectPlugin::closeProject(KateProject *project)
+{
+    QVector<KTextEditor::Document *> projectDocuments;
+    for (auto doc : KTextEditor::Editor::instance()->application()->documents())
+        if (QUrl(project->baseDir()).isParentOf(doc->url().adjusted(QUrl::RemoveScheme)))
+            projectDocuments.push_back(doc);
+
+    // if we have some documents open for this project, ask if we want to close, else just do it
+    if (!projectDocuments.isEmpty()) {
+        QWidget *window = KTextEditor::Editor::instance()->application()->activeMainWindow()->window();
+        const QString title = i18n("Confirm project closing: %1", project->name());
+        const QString text = i18n("Do you want to close the project %1 and the related %2 open documents?", project->name(), projectDocuments.size());
+        if (QMessageBox::Yes != QMessageBox::question(window, title, text, QMessageBox::No | QMessageBox::Yes, QMessageBox::Yes)) {
+            return false;
+        }
+
+        for (auto doc : projectDocuments)
+            KTextEditor::Editor::instance()->application()->closeDocument(doc);
+    }
+
+    Q_EMIT pluginViewProjectClosing(project);
+    if (m_projects.removeOne(project)) {
+        m_fileWatcher.removePath(QFileInfo(project->fileName()).canonicalPath());
+        delete project;
+        return true;
+    }
+
+    return false;
+}
+
 KateProject *KateProjectPlugin::projectForUrl(const QUrl &url)
 {
     if (url.isEmpty() || !url.isLocalFile()) {
